#
# spec file for package xfce4-xkb-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin xkb
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.8.5
Release:        1.2
Summary:        XKB Layout Switcher Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-xkb-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.8/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(garcon-1) >= 4.16.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.40
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.14
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.16.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.16.0
BuildRequires:  pkgconfig(libxklavier) >= 5.3
BuildRequires:  pkgconfig(pango)
Requires:       xfce4-panel >= %{panel_version}
Requires:       xfce4-settings >= 4.11.0
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The XKB plugin allows to setup and switch between multiple XKB keyboard
layouts.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/*.la
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libxkb.so
%{_datadir}/xfce4/panel/plugins/xkb.desktop
%dir %{_datadir}/xfce4/xkb
%{_datadir}/xfce4/xkb/*
%{_datadir}/icons/hicolor/*/apps/org.xfce.panel.xkb.*

%files lang -f %{name}.lang

%changelog
* Mon Jan  6 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.8.5
  * prefs-dialog: Remove unused stock icon name
- Update to version 0.8.4
  * Exit early and remove plugin on non X11 environments
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * Use pango context to adjust dpi (Fixes #56)
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * scan-build: Fix core.CallAndMessage
  * Avoid deprecated rsvg_handle_close()
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Update README consistent with common template
  * build: Add GLib requirement
  * Use xfce_panel_plugin_popup_menu() when possible
  * Implement list of window class names that default to each layout (#33)
  * COPYING: Replace BSD-2-Clause with GPL (#41)
  * Translation Updates
- Remove _service file
* Sun Jul 17 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.3
  * Add optional notification support
    (gxo#panel-plugins/xfce4-xkb-plugin#48)
  * Disable notifications by default
  * Use symbolic icon for notification
  * Add new plugin icon
  * Use Xfce's icon name
  * Fix make distcheck
  * build: Fix intltool lock file problem during make distcheck
  * Fix compilation warnings
  * autoconf: Some updates
  * Update `.gitignore`
  * Translation Updates
* Fri Dec 25 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.2
  * Fix build with panel 4.15
  * Update configure.ac.in syntax
  * scale alternate layout dots to be visible on hi dpi displays
  * Add basic GitLab pipeline
  * Minor build updates
  * Update URLs from goodies.x.o to docs.x.o (bxo#16184)
  * Update .gitignore
  * s/http/https
  * Update Myanmar flag
  * Improve spacing (bxo#14684)
  * Fix compilation warnings
  * Add -lX11 to libxkb_la_LIBADD
  * Translation Updates
- Remove xfce4-xkb-plugin-0.8.0-downgrade-libxklavier-requirement.diff,
  fixed upstream
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Jul 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Use %%license macro for COPYING
* Mon Feb 26 2018 crrodriguez@opensuse.org
- Explicitly require pango and cairo, both are direct
  build deps.
* Tue Oct  3 2017 jengelh@inai.de
- Remove redundant %%clean section.
* Tue Oct  3 2017 seife+obs@b1-systems.com
- update to version 0.8.1
  * Add caps lock indicator for "system" layout style
  * Translation updates
- Fix the build with libxklavier 5.3:
  xfce4-xkb-plugin-0.8.0-downgrade-libxklavier-requirement.diff
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 0.8.0
  * New plugin is not compatible with previous versions
    you will have to add and configure it again!
  * Port to GTK+3
  * Add xfconf support
  * Add new "system" layout style
  * Allow adjusting widget size
  * Allow displaying language name instead of country name
  * Allow hiding tooltip icon
  * Load flags from XDG_DATA_HOME if present
  * Fix Indian flag filename
  * Fix charset for layout names
  * Translation updates
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 0.7.1
  - fix crash in xkb_util_normalize_group_name
- 0.7.0
  - this is a fairly major rework - keyboard layouts are now
    configured through xfce4-keyboard-settings and managed by
    xfsettingsd; xkb-plugin only manages per window/application
    layout prefs and just acts as a layout indicator otherwise
  - many crashes/leaks fixed
  - more descriptive layout/variant names in tooltips/popup menus
  - xfce 4.10 panel compatibility
  - text labels are scaled to the size of text area
  - more flags added
  - layout configs should no longer be lost (this is really handled
    by the code moved to xfce4-settings though)
  - XKB settings not managed by XFCE should no longer be overwritten
    (again, this is really handled by xfce4-settings now)
  - now depends on garcon (used to launch xfce4-keyboard-settings)
- package NEWS instead of ChangeLog file
* Thu Jun 20 2013 gber@opensuse.org
- update to version 0.5.6
  - don't reset xkb settings on panel's save signal
  - check that current group number is sensible
  - fix crash in xkb_util_normalize_group_name
  - window title reflects if layout is added/edited
  - don't overwrite XKB options we don't control
  - disable Edit layout button if no layout is selected
  - fix compiler warning
  - use nicer looking flag dimensions in tooltips
* Tue May 14 2013 gber@opensuse.org
- update to version 0.5.5
  - several crashes fixed
  - text labels are scaled to the size of text area
  - kazakh flag added
  - panel 4.10 compatibility
  - reset xkb config when new keyboard is detected (configs should
    no longer be lost, or at least not as often as before)
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Sat Jan  7 2012 gber@opensuse.org
- update to version 0.5.4.3
  - fix error with incorrect handling variants
  - text size on icon is now adjustable
  - new flag: Cambodia
* Mon Dec  5 2011 gber@opensuse.org
- update to version 0.5.4.2
  - text size on icon is now adjustable
  - new flag: Cambodia
  - Bosnian flag renamed from bs to ba
  - code cleanup
  - fixing memory leaks (bnc#734851)
  - scrolling the plugin button cycle through layouts
  - remove unnedeed g_strdup as g_strconcat already allocates memory
  - switch to libxfce4ui, updated dependencies
  - compilation with libxklavier 5.0 API
  - prevent crashing when removing from panel
  - new flag of Georgia
  - new flag of Serbia, removed flag of Yugoslavia as obsoleted
- dropped all patches, all fixes have been integrated upstream
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
